@@ -12,12 +12,12 @@ OC.L10N.register(
     "Delete" : "លុប",
     "Edit" : "កែប្រែ",
     "Modified" : "បាន​កែ​ប្រែ",
+    "Today" : "ថ្ងៃ​នេះ",
     "Save" : "រក្សាទុក",
     "Reply" : "ឆ្លើយតប",
     "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
     "Description" : "ការ​អធិប្បាយ",
     "seconds ago" : "វិនាទី​មុន",
-    "Shared with you" : "Shared with you",
-    "Today" : "ថ្ងៃ​នេះ"
+    "Shared with you" : "Shared with you"
 },
 "nplurals=1; plural=0;");
