@@ -210,6 +210,10 @@ OC.L10N.register(
     "Set a due date" : "Nastaviť termín",
     "Remove due date" : "Odstrániť termín dokončenia",
     "Select Date" : "Vybrať dátum",
+    "Today" : "Dnes",
+    "Tomorrow" : "Zajtra",
+    "Next week" : "Nasledujúci týždeň",
+    "Next month" : "Nasledujúci mesiac",
     "Save" : "Uložiť",
     "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
     "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
@@ -263,8 +267,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
     "Delete the board?" : "Vymazať nástenku?",
     "Loading filtered view" : "Načítavanie filtrovaného pohľadu",
-    "Today" : "Dnes",
-    "Tomorrow" : "Zajtra",
     "This week" : "Tento týždeň",
     "No due" : "Žiadny termín dokončenia",
     "Search for {searchQuery} in all boards" : "Vyhľadať {searchQuery} na všetkých plochách",
