@@ -63,9 +63,9 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} har återställt bilagan {attachment} till kortet {card}",
     "You have commented on card {card}" : "Du har kommenterat på kortet {card}",
     "{user} has commented on card {card}" : "{user} har kommenterat på kortet {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kortbeskrivning</strong> i Kortlek-appen har ändrats",
-    "Deck" : "Kortlek",
-    "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Kortlek-appen</strong>",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kortbeskrivning</strong> i Deck-appen har ändrats",
+    "Deck" : "Deck",
+    "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Deck-appen</strong>",
     "A <strong>comment</strong> was created on a card" : "En <strong>kommentar</strong> skapades på ett kort",
     "Upcoming cards" : "Kommande kort",
     "Personal" : "Personlig",
@@ -104,7 +104,7 @@ OC.L10N.register(
     "Path is already shared with this card" : "Sökvägen är redan delad med detta kort",
     "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
     "Personal planning and team project organization" : "Personlig planering och projekthantering för teams",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Kortlek är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
     "Card details" : "Kortdetaljer",
     "Add board" : "Lägg till tavla",
     "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
@@ -208,6 +208,8 @@ OC.L10N.register(
     "Set a due date" : "Sätt ett slutdatum",
     "Remove due date" : "Ta bort slutdatum",
     "Select Date" : "Välj datum",
+    "Today" : "Idag",
+    "Tomorrow" : "Imorgon",
     "Save" : "Spara",
     "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
     "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
@@ -241,7 +243,7 @@ OC.L10N.register(
     "Use bigger card view" : "Visa större kort",
     "Show boards in calendar/tasks" : "Visa tavlor i kalender / uppgifter",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsning av Kortlek blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan dock fortfarande integrera med tavlor som har delats med dem.",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsning av Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan dock fortfarande integrera med tavlor som har delats med dem.",
     "Board details" : "Taveldetaljer",
     "Edit board" : "Ändra tavla",
     "Clone board" : "Kopiera tavla",
@@ -261,8 +263,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
     "Delete the board?" : "Ta bort tavlan?",
     "Loading filtered view" : "Laddar filtrerad vy",
-    "Today" : "Idag",
-    "Tomorrow" : "Imorgon",
     "This week" : "Denna vecka",
     "No due" : "Inget slut",
     "Search for {searchQuery} in all boards" : "Sök efter {searchQuery} i alla tavlor",
@@ -277,8 +277,8 @@ OC.L10N.register(
     "Failed to upload {name}" : "Kunde inte ladda upp {name}",
     "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden",
     "Error creating the share" : "Kunde inte skapa delning",
-    "Share with a Deck card" : "Dela med ett Kortlek-kort",
-    "Share {file} with a Deck card" : "Dela {file} med ett Kortlek-kort",
+    "Share with a Deck card" : "Dela med ett Deck-kort",
+    "Share {file} with a Deck card" : "Dela {file} med ett Deck-kort",
     "Share" : "Dela"
 },
 "nplurals=2; plural=(n != 1);");
