@@ -210,6 +210,10 @@ OC.L10N.register(
     "Set a due date" : "设置截止日期",
     "Remove due date" : "移除截止日期",
     "Select Date" : "选择日期",
+    "Today" : "今天",
+    "Tomorrow" : "明天",
+    "Next week" : "下周",
+    "Next month" : "下月",
     "Save" : "保存",
     "The comment cannot be empty." : "注释不能为空。",
     "The comment cannot be longer than 1000 characters." : "注释不能超过 1000 个字符。",
@@ -263,8 +267,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
     "Delete the board?" : "是否删除面板？",
     "Loading filtered view" : "正在加载已筛选的视图",
-    "Today" : "今天",
-    "Tomorrow" : "明天",
     "This week" : "本周",
     "No due" : "没有到期的",
     "Search for {searchQuery} in all boards" : "在所有看板中搜索 {searchQuery}",
