@@ -210,6 +210,10 @@ OC.L10N.register(
     "Set a due date" : "設置到期日",
     "Remove due date" : "移除到期日",
     "Select Date" : "選擇日期",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
+    "Next week" : "下星期",
+    "Next month" : "下個月",
     "Save" : "保存",
     "The comment cannot be empty." : "意見不能為空。",
     "The comment cannot be longer than 1000 characters." : "意見不能超過 1000 個字符。",
@@ -263,8 +267,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你確定你要刪除 {title} 面板嗎？面板內所有數據都將因此被刪除。",
     "Delete the board?" : "是否刪除面板？",
     "Loading filtered view" : "正在加載已過濾視圖",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
     "This week" : "本星期",
     "No due" : "沒有到期的",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
