@@ -118,8 +118,9 @@ class BoardService {
 	/**
 	 * Get all boards that are shared with a user, their groups or circles
 	 */
-	public function getUserBoards(int $since = -1, bool $includeArchived = true): array {
-		return $this->boardMapper->findAllForUser($this->userId, $since, $includeArchived);
+	public function getUserBoards(?int $since = null, bool $includeArchived = true, ?int $before = null,
+								  ?string $term = null): array {
+		return $this->boardMapper->findAllForUser($this->userId, $since, $includeArchived, $before, $term);
 	}
 
 	/**
@@ -178,9 +179,11 @@ class BoardService {
 		/** @var Board $board */
 		$board = $this->boardMapper->find($boardId, true, true);
 		$this->boardMapper->mapOwner($board);
-		foreach ($board->getAcl() as &$acl) {
-			if ($acl !== null) {
-				$this->boardMapper->mapAcl($acl);
+		if ($board->getAcl() !== null) {
+			foreach ($board->getAcl() as $acl) {
+				if ($acl !== null) {
+					$this->boardMapper->mapAcl($acl);
+				}
 			}
 		}
 		$permissions = $this->permissionService->matchPermissions($board);
